@import "base_style.css";

#inner {
  position: relative;
  height: inherit;
  clear: both;
  height: 1500px;
  width: 80%;
}

.args, .loading_area {
  position: absolute;
  background: var(--color_lines_light);
  color: var(--text_dark);
  text-align: center;
  margin: 20px;
  border: 2px solid var(--box_background);
  top: 10px;
  padding: 20px;
  border-radius: 10px;
  height: inherit;
}

embed {
  width: 100%;
  height: 1000px;
}

.html {
  resize: vertical;
}

.args hr, .loading_area hr {
  border: 2px solid var(--box_background);
}

.args {
  width: 20%;
  border-radius: 15px;
  left: 10px;
  word-wrap: break-word;
}

.loading_area {
  width: 68%;
  right: 10px;
  vertical-align: middle;
}

.loader {
    border: 20px solid grey;
    border-top: 20px solid #e0fffc;
    border-radius: 50%;
    margin: auto;
    width: 100px;
    height: 100px;
    align-items: center;
    animation: spin 2s linear infinite;
    vertical-align: middle;
}

.args_list {
  font-size: var(--font_mid);
  text-align: left;
}

td {
  border-bottom: 2px solid var(--box_background);
  border-collapse: collapse;
  width: 50%;
}

tr {
  word-wrap: break-word;
}

.results {
  padding: 20px;
  word-wrap: break-word;
}

.html {
  background-color: white;
  width: 100%;
  height: auto;
}

.prophage_table {
  width: auto;
  margin-left: auto;
  margin-right: auto;
  border: 2px solid var(--box-background)
}

.prophage_row {
  border-top: 2px solid var(--box_background);
  border-left: 2px solid var(--box_background);
  border-right: 2px solid var(--box_background);
}

.bact_name {
  text-align: right;
}

.count {
  width: 30%;
}

.result_links {
  text-align: left;
  color: var(--text-text_dark_2);
  text-decoration: underline;
}

@keyframes spin {
  0% { transform: rotate(0deg); }
  100% { transform: rotate(360deg);}
}
