{% extends 'base.html' %}

{% block stylelink %}"{{ url_for('static', filename='css/loading_style.css') }}"{% endblock %}

{% block content %}

<script type="text/javascript">
  window.onload = function() {
  };
</script>

<div class="inner" id="inner">
  <div class="args">
    Arguments
    <hr>
    <br>
    <table class="args_list" width=100%>
      {% block args_content %}{% endblock %}
    </table>
  </div>
  <div class="loading_area">{% block results %}{% endblock %}</div>
</div>

{% endblock %}
