@import "base_style.css";

.contents {
  align-items: center;
  margin-left: 15px;
  padding-top: 5px;
  padding-bottom: 5px;
  padding-left: 10px;
  padding-right: 25px;
  font-size: 16px;
  background-color: var(--input_light);
  color: var(--dark_background);
  border: 2px solid var(--dark_background);
  border-radius: 2px;
  text-align: left;
  width: 30%;
}

.contents ul {
  padding-left: 8%;
}

.contents ul ul {
  padding-left: 10%;
  /*list-style-type: none;*/
}

.contents ul ul ul {
  padding-left: 12%;
}

#top {
  display: none;
  position: fixed;
  bottom: 100px;
  right: 30px;
  z-index: 99;
}
