/* green-tan */
:root {
  --dark_background: #1c3334;
  --mid_background: #ffe3bf;
  --light_background: #4a7d80;
  --color_lines_dark: #d9b08c;
  --color_lines_light: #ffcb9a;
  --box_background: #275152;
  --text_light: #c4c4c4;
  --text_mid: #c4fffb;
  --text_dark: #222222;
  --text_dark_2: #073835;
  --input_dark: #333333;
  --input_mid: #888888;
  --input_light: #d1d1d1;

  --font_normal: 22px;
  --font_mid: 18px;
  --font_small: 14px;
}

/* black-red-green
:root {
  --dark_background: black;
  --mid_background:;
  --color_lines_dark: #edf5e1;
  --color_lines_light: #907163;
  --box_background: #376e6f;
  --text_light: #c4c4c4;
  --text_mid: #c4fffb;
  --text_dark: #222222;
  --text_dark_2:;
  --input_dark: #333333;
  --input_mid: #888888;
  --input_light: #d1d1d1;
}
*/

/*green-pink
:root {
  --dark_background: #1c3334;
  --mid-background: #d4fcf2;
  --color_lines_dark: #2e151b;
  --color_lines_light: #da7893;
  --box_background: #376e6f;
  --text_light: #c4c4c4;
  --text_mid: #c4fffb;
  --text_dark_2: black;
  --text_dark: black;
  --input_dark: #333333;
  --input_mid: #888888;
  --input_light: #d1d1d1;
}*/

html {
  font-family: "Helvetica", sans-serif;
  background: var(--dark_background);
}

body {
  font-size: var(--font_normal);
  line-height: 1.5;
  margin-top: 100px;
  margin-bottom: 400px;
}

hr {
  border: 2px solid var(--color_lines_dark);
}

.inner {
  background: var(--box_background);
  color: var(--text_light);
  width: 50%;
  align-items: center;
  margin: auto;
  padding: 50px;
  border: 4px solid var(--color_lines_light);
  border-radius: 15px;
  text-align: justify;
}

.args_form {
  width: 50%
  margin: auto;
}

.navbar {
  top: 0;
  position: fixed;
  width: 100%;
  overflow: hidden;
  padding: 10px;
  z-index: 99;
  background: var(--color_lines_dark);
  color: var(--text_dark);
}

.navbar a {
  background: inherit;
  color: inherit;
  text-decoration: none;
  padding: 14px 16px;
}

.navbar a:hover {
  color: var(--text_mid);
  background-color: var(--color_lines_light);
}

.navbar a:visited {
  color: inherit;
}

a {
  text-decoration: none;
  color: inherit;
}

a:visited {
  color: inherit;
}

.ext_links {
  text-decoration: none;
  color: var(--color_lines_light);
}

.ext_links:visited {
  text-decoration: none;
  color: var(--color_lines_dark);
}

#buttons {
  margin: auto;
  text-align: center;
  padding-left: 2%;
  padding-right: 2%;
  border-radius: 2px;
}

button {
  border: none;
  outline: none;
  cursor: pointer;
  padding: 15px;
  border-radius: 5px;
  font-size: 18px;
  background-color: var(--color_lines_dark);
  color: var(--text_dark_2);
}

.banner {
  text-decoration: none;
  background: var(--mid_background);
  color: var(--text_dark_2);
  margin: auto;
  padding: 25px;
  margin-top: 50px;
  margin-bottom: 50px;
  right: 0;
}


form {
  margin-left: 20%;
  width: 50%;
  border: 1px solid black;
  border-radius: 15px;
  padding: 10px;
  align-items: center;
}

label {
  margin-right: 5px;
  text-align: left;
}

h1, #banner_link {
  font-size: 48px;
  color: inherit;
  text-align: center;
  text-shadow: 1px;
  text-decoration: none;
}

h2 {
  text-align: center;
  font-size: 40px;
}

h3 {
  font-size: 32px;
}

h4 {
  font-size: 24px;
}

h5 {
  font-size: 22px;
}

.page_heading {
  color: var(--text_mid);
}

.citation {
  border-left: 5px solid var(--color_lines_dark);
  padding-left: 20px;
}

.footer {
  height: 75px;
  padding-left: 30%;
  bottom: 0;
  position: fixed;
  margin-bottom: 0;
  width: 100%;
  justify-content: center;
  background: var(--color_lines_dark)
}

.logos {
  height: 45px;
  margin-left: 20px;
  padding: 20px;
  padding-left: 20px;
  right: 0;
  margin: auto;
}
