{% extends 'base.html' %}

{% block stylelink %}
  "{{ url_for('static', filename='css/program_style.css') }}"
{% endblock %}
{% block script %}
  "{{url_for('static', filename='js/arguments.js')}}"
{% endblock %}

{% block content %}

<script type="text/javascript">
  window.onload = function() {
    get_core_list("{{cpu_cores}}");
  };

</script>

  {% block heading %}{% endblock %}

  {% block form_content %}
  {% endblock %}


{% endblock %}
